/**
 * @file
 * Defines Javascript behaviors for the cookies module.
 */;

(function (Drupal, drupalSettings) {
  'use strict';

  document.cookiesjsr = {
    apiUrl: '',
    configQuery: '/cookiesjsr/%lang_id/services.json',
  }

  /**
   * Define defaults.
   */
  Drupal.behaviors.cookiesjsr = {
    services: {
      basis: {
        activate: function () {console.log('basis activate')},
        fallback: function () {console.log('basis fallback')}
      }
    },

    invoguePlugins: function () {
      document.dispatchEvent(new Event('cookiesjsrAvailable'));
      // document.addEventListener('cookiesjsrAvailable', function () {}),
    },

    attach: function (context, settings) {
      var serviceObjects = this.services;

      // Catch event from cookiesjsr and activate (fallback) the service.
      document.addEventListener('cookiesjsrUserConsent', function(event) {
        var services = (typeof event.detail.services === 'object')
          ? event.detail.services : {};
        for (let sid in services) {
          if(typeof serviceObjects[sid] === 'object') {
            if(services[sid] === true
              && typeof serviceObjects[sid].activate === 'function') {
              serviceObjects[sid].activate();
            } else if(typeof serviceObjects[sid].fallback === 'function') {
              serviceObjects[sid].fallback();
            }
          }
        }
      });

      this.invoguePlugins();
    }
  }
})(Drupal, drupalSettings);
